@@ -1,7 +1,7 @@
 package Dist::Zilla::Plugin::Rinci::ScriptFromFunc;
 
-our $DATE = '2015-01-03'; # DATE
-our $VERSION = '0.05'; # VERSION
+our $DATE = '2015-01-10'; # DATE
+our $VERSION = '0.06'; # VERSION
 
 use 5.010001;
 use strict;
@@ -31,6 +31,7 @@ our %KNOWN_SCRIPT_SPEC_PROPS = (
     log => 1,
     ssl_verify_hostname => 1,
     snippet_before_instantiate_cmdline => 1,
+    config_filename => 1,
 );
 
 sub _get_meta {
@@ -138,6 +139,7 @@ sub gather_files {
             "$cmdline_mod->new(\n",
             "    url => ", dump($url), ",\n",
             (defined($scriptspec{log}) ? "    log => " . dump($scriptspec{log}) . ",\n" : ""),
+            (defined($scriptspec{config_filename}) ? "    config_filename => " . dump($scriptspec{config_filename}) . ",\n" : ""),
             ")->run;\n",
             "\n",
         );
@@ -172,7 +174,7 @@ Dist::Zilla::Plugin::Rinci::ScriptFromFunc - Create or fill out script details f
 
 =head1 VERSION
 
-This document describes version 0.05 of Dist::Zilla::Plugin::Rinci::ScriptFromFunc (from Perl distribution Dist-Zilla-Plugin-Rinci-ScriptFromFunc), released on 2015-01-03.
+This document describes version 0.06 of Dist::Zilla::Plugin::Rinci::ScriptFromFunc (from Perl distribution Dist-Zilla-Plugin-Rinci-ScriptFromFunc), released on 2015-01-10.
 
 =head1 SYNOPSIS
 
